<?php
/*
Plugin Name: RSS What's New
Plugin URI: https://it-soudan.com/it/rss-whats-new/
Description: Show What's new list of any site with RSS
Version: 0.1.0
Author: koyacode
Author URI: https://it-soudan.com/
Text Domain: rss-whats-new
License: GPL2
License URI: https://www.gnu.org/licenses/gpl-2.0.html

{Plugin Name} is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 2 of the License, or
any later version.
 
{Plugin Name} is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with {Plugin Name}. If not, see {License URI}.
*/

include_once( ABSPATH . WPINC . '/feed.php' );

class RSS_Fetcher {
    
    const FEED_NUM_MAX = 30;
    const FEED_NUM_DEFAULT = 4;

    function fetch( $feeduri, $num ) {
        if ( $feeduri === '' ) {
            return '';
        }

        $feeduri = esc_url_raw( $feeduri );
        // $feed_num = $num;
        if ( $num < 0 ) {
            $num = self::FEED_NUM_DEFAULT;
        }
        if ( $num > self::FEED_NUM_MAX ) {
            $num = self::FEED_NUM_MAX;
        }

        $rss = fetch_feed( $feeduri );
        if ( ! is_wp_error( $rss ) ) {
            $maxitems = $rss->get_item_quantity( $num );
            $rss_items = $rss->get_items( 0, $maxitems );
        }
    
        $list = '<ul class="rss-whats-new">';
        if ( !$rss_items ) {
            // no new item
        } else {
            foreach ( $rss_items as $i ) {
                $permalink = esc_url( $i->get_permalink());
                $title = esc_html( $i->get_title());
                $description = esc_html( $i->get_description());
                $description = $i->get_description();
                $date = esc_html( $i->get_date("Y-m-d"));

                $list .= '<li><a href="' . $permalink . '">' . $title . '</a><br>' . $description . '<p class="rss-whats-new-date">' . $date . '</p></li>';
            }
        }
        $list .= '</ul>';
        return $list;
    }
}

function rsswhatsnew_fetch_rss( $feeduri, $num ) {
    $RSSFetcher = new RSS_Fetcher();
    return $RSSFetcher->fetch( $feeduri, $num );
}

function rsswhatsnew_handler( $atts ) {
    $a = shortcode_atts( array(
        'feeduri' => '',
        'num'     => RSS_Fetcher::FEED_NUM_DEFAULT,
    ), $atts );
    return rsswhatsnew_fetch_rss( $a['feeduri'], $a['num']);
}
add_shortcode( 'rss-whats-new', 'rsswhatsnew_handler' );

function rsswhatsnew_register_my_styles() {
	wp_enqueue_style(
        'style-name',
        plugins_url( 'css/rss-whats-new.css', __FILE__ )
    );
}
add_action( 'wp_enqueue_scripts', 'rsswhatsnew_register_my_styles' );

?>
